import {  IgrDataGrid, IgrTemplateHeader, IgrTemplateHeaderCellUpdatingEventArgs, IgrTextColumn, IgrTemplateColumn, IgrTemplateCellInfo, IgrTemplateCellUpdatingEventArgs} from 'igniteui-react-grids';
import { useState } from 'react';

const products = [
    { Symbol: 'AAPL1', Side: 'Buy', },
    { Symbol: 'IBM2', Side: 'Sell', },
    { Symbol: 'TSLA3', Side: 'Buy', }

];

export default function InfragisticsGrid() {
const [gridData, setGridData] = useState(products);
const [gridReference, setGridReference] = useState<IgrDataGrid>();
const customHeader: IgrTemplateHeader = new IgrTemplateHeader({});

const gridRef = (event) => {
    setGridReference(event);
}

const onCustomHeaderUpdating = (args: IgrTemplateHeaderCellUpdatingEventArgs) => {
      const content = args.content as HTMLDivElement;
      let checkAll: HTMLInputElement | null = null;
      if (content.childElementCount === 0) {
        checkAll = document.createElement('input');
        checkAll.setAttribute('type', 'checkbox');
        checkAll.setAttribute('class', 'form-check-input');
        checkAll.setAttribute('id', 'form-checkAll-input');
        content.appendChild(checkAll);
        if (content.parentElement != null) {
          content.parentElement.style.pointerEvents = 'none';
        }
        checkAll.style.pointerEvents = 'auto';
      } else {
        checkAll = content.children[0] as HTMLInputElement;
      }
      checkAll.style.marginTop = '10px'
  };

customHeader.cellUpdating = (sender, args) => {
    if (gridReference) {
      onCustomHeaderUpdating(args);
    }
  };

  const onCheckboxCellUpdating = (sender: IgrTemplateColumn, args: IgrTemplateCellUpdatingEventArgs) => {
    const content = args.content as HTMLDivElement;
    let check: HTMLInputElement | null = null;
    if (content.childElementCount === 0) {
      check = document.createElement('input');
      check.setAttribute('type', 'checkbox');
      check.setAttribute('class', 'form-check-input');
      check.addEventListener('change', (evt) => {
        const newValue = (evt.target as HTMLInputElement).checked;
        const itemToUpdate = (args.cellInfo as IgrTemplateCellInfo).rowItem;
        itemToUpdate.checked = newValue;
      });
      content.appendChild(check);
    } else {
      check = content.children[0] as HTMLInputElement;
    }
  };

    return (
        <div className="container">
     
            <IgrDataGrid
                height="calc(100% - 40px)"
                width="100%"
                ref={gridRef}
                columnResizingAnimationMode="Interpolate"
                columnResizingMode="Deferred"
                columnResizingSeparatorWidth={1}
                autoGenerateColumns={false}
                defaultColumnMinWidth={100}
                dataSource={gridData}
                isColumnOptionsEnabled="true"
                >
                
                <IgrTemplateColumn width='50' field='checked' headerText='checkbox' header={customHeader} cellUpdating={onCheckboxCellUpdating}
                />
                <IgrTextColumn field="Symbol" horizontalAlignment="center" isEditable={false}/>
                <IgrTextColumn field="Side" horizontalAlignment="center" isEditable={false}/>

            </IgrDataGrid>
        </div>
    );

}



